@@ -1,3 +1,5 @@
+from typing import Callable
+
 from prompt_toolkit.application import get_app
 from prompt_toolkit.enums import EditingMode
 from prompt_toolkit.key_binding.vi_state import InputMode
@@ -5,17 +7,17 @@ from prompt_toolkit.key_binding.vi_state import InputMode
 from mycli.packages import special
 
 
-def create_toolbar_tokens_func(mycli, show_fish_help):
+def create_toolbar_tokens_func(mycli, show_fish_help: Callable) -> Callable:
     """Return a function that generates the toolbar tokens."""
 
-    def get_toolbar_tokens():
+    def get_toolbar_tokens() -> list[tuple[str, str]]:
         result = [("class:bottom-toolbar", " ")]
 
         if mycli.multi_line:
             delimiter = special.get_current_delimiter()
             result.append((
                 "class:bottom-toolbar",
-                " ({} [{}] will end the line) ".format("Semi-colon" if delimiter == ";" else "Delimiter", delimiter),
+                f' ({"Semi-colon" if delimiter == ";" else "Delimiter"} [{delimiter}] will end the line) ',
             ))
 
         if mycli.multi_line:
@@ -23,7 +25,7 @@ def create_toolbar_tokens_func(mycli, show_fish_help):
         else:
             result.append(("class:bottom-toolbar.off", "[F3] Multiline: OFF  "))
         if mycli.prompt_app.editing_mode == EditingMode.VI:
-            result.append(("class:bottom-toolbar.on", "Vi-mode ({})".format(_get_vi_mode())))
+            result.append(("class:bottom-toolbar.on", f"Vi-mode ({_get_vi_mode()})"))
 
         if mycli.toolbar_error_message:
             result.append(("class:bottom-toolbar", "  " + mycli.toolbar_error_message))
@@ -40,7 +42,7 @@ def create_toolbar_tokens_func(mycli, show_fish_help):
     return get_toolbar_tokens
 
 
-def _get_vi_mode():
+def _get_vi_mode() -> str:
     """Get the current vi mode for display."""
     return {
         InputMode.INSERT: "I",
