@@ -1,3 +1,5 @@
+# type: ignore
+
 """Steps for behavioral style tests are defined in this module.
 
 Each step is defined by the string decorating it. This string is used
@@ -5,6 +7,7 @@ to call the step in "*.feature" file.
 
 """
 
+import datetime
 import tempfile
 from textwrap import dedent
 
@@ -29,6 +32,16 @@ def step_ctrl_d(context):
     context.exit_sent = True
 
 
+@when('we send "ctrl + o, ctrl + d"')
+def step_ctrl_o_ctrl_d(context):
+    """Send ctrl + o, ctrl + d to insert the quoted date."""
+    context.cli.send("SELECT ")
+    context.cli.sendcontrol("o")
+    context.cli.sendcontrol("d")
+    context.cli.send(" AS dt")
+    context.cli.sendline("")
+
+
 @when(r'we send "\?" command')
 def step_send_help(context):
     r"""Send \?
@@ -45,7 +58,7 @@ def step_send_source_command(context):
     with tempfile.NamedTemporaryFile() as f:
         f.write(b"\\?")
         f.flush()
-        context.cli.sendline("\\. {0}".format(f.name))
+        context.cli.sendline(f"\\. {f.name}")
         wrappers.expect_exact(context, context.conf["pager_boundary"] + "\r\n", timeout=5)
 
 
@@ -75,6 +88,29 @@ def step_see_found(context):
     )
 
 
+@then("we see the date")
+def step_see_date(context):
+    # There are some edge cases in which this test could fail,
+    # such as running near midnight when the test database has
+    # a different TZ setting than the system.
+    date_str = datetime.datetime.now().strftime("%Y-%m-%d")
+    wrappers.expect_exact(
+        context,
+        context.conf["pager_boundary"]
+        + "\r"
+        + dedent(f"""
+            +------------+\r
+            | dt         |\r
+            +------------+\r
+            | {date_str} |\r
+            +------------+\r
+            \r
+        """)
+        + context.conf["pager_boundary"],
+        timeout=5,
+    )
+
+
 @then("we confirm the destructive warning")
 def step_confirm_destructive_command(context):  # noqa
     """Confirm destructive command."""
